capture log close
log using "part1_weights", replace text

//  project:     A White Social Movement...
//  author:      Fabio Rojas, Michael T. Heaney, Muna Adem
//  Data:        antiwar2007_old.dta
//  Created      2019-09-18
//  Updated:     2023-03-02


// Task 1:        Change some events 
// Task 2:        Create Survey Weights
// Task 3:        Declare Survey Design 


version 	17.0
clear 		all
set 		linesize 80
matrix drop _all
set more 	off, permanently


// open dataset 
use "antiwar2007.dta", clear 

********************************************************************************
                      **Adding/Replacing BactchNumbers**
********************************************************************************
*This is for event=200701
*Changing 200705--Something got recoded wrong so we are now making sure that the 
* batch number and event number match for 200705
replace EventNumber = 200705 in 1434/1552 

*Adding the black-protest as event
replace EventNumber = 201007 in 6073/6133
replace EventNumber = 201008 in 6134/6164
replace EventNumber = 201009 in 6165/6201
replace EventNumber = 201010 in 6202/6334

* Adding BatchNumber 
replace BatchNumber = 201028 in 6073/6084
replace BatchNumber = 201029 in 6085/6101
replace BatchNumber = 201030 in 6102/6106
replace BatchNumber = 201031 in 6107/6112
replace BatchNumber = 201032 in 6113/6133
replace BatchNumber = 201033 in 6134/6153 
replace BatchNumber = 201034 in 6154/6164
replace BatchNumber = 201035 in 6165/6186 
replace BatchNumber = 201036 in 6187/6201 
replace BatchNumber = 201037 in 6202/6222
replace BatchNumber = 201038 in 6223/6258
replace BatchNumber = 201039 in 6259/6283 
replace BatchNumber = 201040 in 6284/6307 
replace BatchNumber = 201041 in 6308/6333
replace BatchNumber = 201042 in 6334
replace Year = 2010 in 6134/6334

********************************************************************************
					**Generating Survey Weights Using EventNumber**
********************************************************************************		
gen pw=1
replace  pw= 1.0274851   if EventNumber==200701 & Female==0 & White==.
replace  pw= 0.981307078 if EventNumber==200701 & Female==1 & White==.
replace  pw= 0.98575682  if EventNumber==200701 & Female==. & White==1
replace  pw= 1.255935423 if EventNumber==200701 & Female==. & Black==1
replace  pw= 0.97962963  if EventNumber==200701 & Female==. & Latino==1
replace  pw= 1.043124143 if EventNumber==200701 & Female==. & Asian==1
replace  pw= 1.224537037 if EventNumber==200701 & Female==. & Other==1
replace  pw = 0.996375435 if EventNumber==200701 & Female==0& White==1
replace  pw = 1.632716049 if EventNumber==200701& Female==0& Black==1
replace  pw = 1.088477366 if EventNumber==200701 & Female==0 & Latino==1
replace  pw = 1.496656379 if EventNumber==200701& Female==0 & Asian==1
replace  pw = 0.816358025 if EventNumber==200701& Female==0 & Other==1
replace  pw = 0.980920314  if EventNumber==200701 & Female==1 & White==1
replace  pw = 1.156507202 if EventNumber==200701 & Female==1 & Black==1
replace  pw = 0.890572391 if EventNumber==200701 & Female==1 & Latino==1
replace  pw = 0.816358025 if EventNumber==200701 & Female==1 & Asian==1
replace  pw = 2.449074074 if EventNumber==200701 & Female==1 & Other==1

replace  pw= 1.048934668  if EventNumber==200703 & Female==0 & White==.
replace  pw= 0.956834429 if EventNumber==200703 & Female==1 & White==.
replace  pw= 0.998451486  if EventNumber==200703 & Female==. & White==1
replace  pw= 0.976924861 if EventNumber==200703 & Female==. & Black==1
replace  pw= 1.146258503 if EventNumber==200703 & Female==. & Latino==1
replace  pw= 0.859693878 if EventNumber==200703 & Female==. & Asian==1
replace  pw= 1.432823129 if EventNumber==200703 & Female==. & Other==1
replace  pw = 1.026684775 if EventNumber==200703 & Female==0& White==1
replace  pw = 1.058084772 if EventNumber==200703 & Female==0& Black==1
replace  pw = 2.005952381 if EventNumber==200703 & Female==0 & Latino==1
replace  pw = 0.859693878 if EventNumber==200703 & Female==0 & Asian==1
replace  pw = 1.289540816 if EventNumber==200703 & Female==0 & Other==1
replace  pw = 0.97234342 if EventNumber==200703 & Female==1 & White==1
replace  pw = 0.859693878 if EventNumber==200703 & Female==1 & Black==1
replace  pw = 0.859693878 if EventNumber==200703 & Female==1 & Latino==1
replace  pw = 0.859693878 if EventNumber==200703 & Female==1 & Asian==1
replace  pw = 1.719387755 if EventNumber==200703 & Female==1 & Other==1

replace  pw= 1.03742515  if EventNumber==200704 & Female==0 & White==.
replace  pw= 0.97006 if EventNumber==200704 & Female==1 & White==.
replace  pw= 0.982342427  if EventNumber==200704 & Female==. & White==1
replace  pw= 1.198309264 if EventNumber==200704 & Female==. & Black==1
replace  pw= 1.080293958 if EventNumber==200704 & Female==. & Latino==1
replace  pw= 1.03742515 if EventNumber==200704 & Female==. & Asian==1
replace  pw= 0.905389222 if EventNumber==200704 & Female==. & Other==1
replace  pw = 1.009712802 if EventNumber==200704 & Female==0& White==1
replace  pw = 1.226047904 if EventNumber==200704 & Female==0& Black==1
replace  pw = 1.21257485 if EventNumber==200704 & Female==0 & Latino==1
replace  pw =1.030688623 if EventNumber==200704 & Female==0 & Asian==1
replace  pw = 0.943113772 if EventNumber==200704 & Female==0 & Other==1
replace  pw = 0.961294279 if EventNumber==200704 & Female==1 & White==1
replace  pw = 1.167103293 if EventNumber==200704 & Female==1 & Black==1
replace  pw = 0.982823826 if EventNumber==200704 & Female==1 & Latino==1
replace  pw = 1.061002994 if EventNumber==200704 & Female==1 & Asian==1
replace  pw = 0.848802395 if EventNumber==200704 & Female==1 & Other==1

replace  pw= 1.03742515   if EventNumber==200705 & Female==0 & White==.
replace  pw= 0.97005988 if EventNumber==200705 & Female==1 & White==.
replace  pw= 0.982342427  if EventNumber==200705 & Female==. & White==1
replace  pw= 1.198309264 if EventNumber==200705 & Female==. & Black==1
replace  pw= 1.080293958  if EventNumber==200705 & Female==. & Latino==1
replace  pw= 1.03742515 if EventNumber==200705 & Female==. & Asian==1
replace  pw= 0.905389222 if EventNumber==200705 & Female==. & Other==1
replace  pw = 1.009712802 if EventNumber==200705 & Female==0 & White==1
replace  pw = 1.226047904 if EventNumber==200705 & Female==0 & Black==1
replace  pw = 1.21257485 if EventNumber==200705 & Female==0 & Latino==1
replace  pw = 1.030688623 if EventNumber==200704 & Female==0 & Asian==1
replace  pw = 0.943113772 if EventNumber==200705 & Female==0 & Other==1
replace  pw = 0.961294279  if EventNumber==200705 & Female==1 & White==1
replace  pw = 1.167103293 if EventNumber==200701 & Female==1 & Black==1
replace  pw = 0.982823826 if EventNumber==200701 & Female==1 & Latino==1
replace  pw = 1.061002994 if EventNumber==200701 & Female==1 & Asian==1
replace  pw = 0.848802395 if EventNumber==200701 & Female==1 & Other==1

replace  pw= 0.889295889  if EventNumber==200708 & Female==0 & White==.
replace  pw= 0.831549403 if EventNumber==200708 & Female==1 & White==.
replace  pw= 0.858371126  if EventNumber==200708 & Female==. & White==1
replace  pw= 0.853432282 if EventNumber==200708 & Female==. & Black==1
replace  pw= 0.886621315 if EventNumber==200708 & Female==. & Latino==1
replace  pw= 0.782312925 if EventNumber==200708 & Female==. & Asian==1
replace  pw= 0.782312925 if EventNumber==200708 & Female==. & Other==1
replace  pw = 0.892857143 if EventNumber==200708 & Female==0& White==1
replace  pw = 0.880102041 if EventNumber==200708 & Female==0& Black==1
replace  pw = 0.894071914 if EventNumber==200708 & Female==0 & Latino==1
replace  pw =0.782312925 if EventNumber==200708 & Female==0 & Asian==1
replace  pw = 0.782312925 if EventNumber==200708 & Female==0 & Other==1
replace  pw = 0.832784727 if EventNumber==200708 & Female==1 & White==1
replace  pw = 0.782312925 if EventNumber==200708 & Female==1 & Black==1
replace  pw = 0.880102041 if EventNumber==200708 & Female==1 & Latino==1
replace  pw = 0.782312925 if EventNumber==200708 & Female==1 & Asian==1
replace  pw = 0.782312925 if EventNumber==200708 & Female==1 & Other==1

replace  pw= 1.032986111  if EventNumber==200709 & Female==0 & White==.
replace  pw= 0.973314607 if EventNumber==200709 & Female==1 & White==.
replace  pw= 0.971507353  if EventNumber==200709 & Female==. & White==1
replace  pw= 1.0390625 if EventNumber==200709 & Female==. & Black==1
replace  pw=0.991666667 if EventNumber==200709 & Female==. & Latino==1
replace  pw= 1.53125 if EventNumber==200709 & Female==. & Asian==1
replace  pw = 0.995689655 if EventNumber==200709 & Female==0& White==1
replace  pw = 1.203125 if EventNumber==200709 & Female==0& Black==1
replace  pw = 1 if EventNumber==200709 & Female==0 & Latino==1
replace  pw =1.75 if EventNumber==200709 & Female==0 & Asian==1
replace  pw =0.953525641 if EventNumber==200709 & Female==1 & White==1
replace  pw = 0.875 if EventNumber==200709 & Female==1 & Black==1
replace  pw = 0.984375 if EventNumber==200709 & Female==1 & Latino==1
replace  pw = 1.458333333 if EventNumber==200709 & Female==1 & Asian==1

replace  pw= 1.061887571 if EventNumber==200710 & Female==0 & White==.
replace  pw= 0.945848375 if EventNumber==200710 & Female==1 & White==.
replace  pw= 1.018635964  if EventNumber==200710 & Female==. & White==1
replace  pw= 0.837545126 if EventNumber==200710 & Female==. & Black==1
replace  pw= 0.977135981 if EventNumber==200710 & Female==. & Latino==1
replace  pw= 0.901971675 if EventNumber==200710 & Female==. & Asian==1
replace  pw= 1.25631769 if EventNumber==200710 & Female==. & Other==1
replace  pw = 1.087845969 if EventNumber==200710 & Female==0& White==1
replace  pw = 0.837545126 if EventNumber==200710 & Female==0& Black==1
replace  pw = 1.088808664 if EventNumber==200710 & Female==0 & Latino==1
replace  pw =0.930605696 if EventNumber==200710 & Female==0 & Asian==1
replace  pw = 0.958427928 if EventNumber==200710 & Female==1 & White==1
replace  pw =0.837545126 if EventNumber==200710 & Female==1 & Black==1
replace  pw = 0.837545126 if EventNumber==200710 & Female==1 & Latino==1
replace  pw = 0.837545126 if EventNumber==200710 & Female==1 & Asian==1
replace  pw = 1.25631769 if EventNumber==200710 & Female==1 & Other==1

replace  pw= 1.038402062  if EventNumber==200801 & Female==0 & White==.
replace  pw= 0.96061327 if EventNumber==200801 & Female==1 & White==.
replace  pw= 0.973346744  if EventNumber==200801 & Female==. & White==1
replace  pw= 1.221649485 if EventNumber==200801 & Female==. & Black==1
replace  pw= 0.912164948 if EventNumber==200801 & Female==. & Latino==1
replace  pw= 1.085910653 if EventNumber==200801 & Female==. & Asian==1
replace  pw= 4.072164948 if EventNumber==200801 & Female==. & Other==1
replace  pw = 1.028757461 if EventNumber==200801 & Female==0& White==1
replace  pw = 1.357388316 if EventNumber==200801 & Female==0& Black==1
replace  pw = 0.872606775 if EventNumber==200801 & Female==0 & Latino==1
replace  pw =1.628865979 if EventNumber==200801 & Female==0 & Asian==1
replace  pw = 0.925492034 if EventNumber==200801 & Female==1 & White==1
replace  pw = 0.81443299 if EventNumber==200801 & Female==1 & Black==1
replace  pw = 0.962511715 if EventNumber==200801 & Female==1 & Latino==1
replace  pw = 0.81443299 if EventNumber==200801 & Female==1 & Asian==1
replace  pw = 2.443298969 if EventNumber==200801 & Female==1 & Other==1

replace  pw= 1.074231669  if EventNumber==200802 & Female==0 & White==.
replace  pw= 0.9226591513 if EventNumber==200802 & Female==1 & White==.
replace  pw= 0.992422116  if EventNumber==200802 & Female==. & White==1
replace  pw= 1.216918988 if EventNumber==200802 & Female==. & Black==1
replace  pw= 0.981704322 if EventNumber==200802 & Female==. & Latino==1
replace  pw= 0.99156362 if EventNumber==200802 & Female==. & Asian==1
replace  pw= 1.277013752 if EventNumber==200802 & Female==. & Other==1
replace  pw = 1.048248099 if EventNumber==200802 & Female==0& White==1
replace  pw = 1.455795678 if EventNumber==200802 & Female==0& Black==1
replace  pw = 1.123772102 if EventNumber==200802 & Female==0 & Latino==1
replace  pw =0.975174138 if EventNumber==200802 & Female==0 & Asian==1
replace  pw = 1.532416503 if EventNumber==200802 & Female==0 & Other==1
replace  pw = 0.932556096 if EventNumber==200802 & Female==1 & White==1
replace  pw = 0.875666573 if EventNumber==200802 & Female==1 & Black==1
replace  pw = 0.856350399 if EventNumber==200802 & Female==1 & Latino==1
replace  pw = 1.021611002 if EventNumber==200802 & Female==1 & Asian==1
replace  pw = 1.149312377 if EventNumber==200802 & Female==1 & Other==1

replace  pw= 0.964131994  if EventNumber==200803 & Female==0 & White==.
replace  pw= 1.055432373 if EventNumber==200803 & Female==1 & White==.
replace  pw= 1.039236479  if EventNumber==200803 & Female==. & White==1
replace  pw= 1.365853659 if EventNumber==200803 & Female==. & Black==1
replace  pw= 0.682926829 if EventNumber==200803 & Female==. & Latino==1
replace  pw = 1.001626016 if EventNumber==200803 & Female==0& White==1
replace  pw = 1.109756098 if EventNumber==200803 & Female==1 & White==1
replace  pw = 1.365853659 if EventNumber==200803 & Female==1 & Black==1
replace  pw = 0.682926829 if EventNumber==200803 & Female==1 & Latino==1

replace  pw= 1.033118511  if EventNumber==200804 & Female==0 & White==.
replace  pw= 0.971744738 if EventNumber==200804 & Female==1 & White==.
replace  pw= 1.005529938  if EventNumber==200804 & Female==. & White==1
replace  pw= 1.145270584 if EventNumber==200804 & Female==. & Black==1
replace  pw= 0.948234784 if EventNumber==200804 & Female==. & Latino==1
replace  pw= 0.879272255 if EventNumber==200804 & Female==. & Asian==1
replace  pw= 0.969785575 if EventNumber==200804 & Female==. & Other==1
replace  pw = 1.017403789 if EventNumber==200804 & Female==0& White==1
replace  pw = 1.312940471 if EventNumber==200804 & Female==0& Black==1
replace  pw = 0.969785575 if EventNumber==200804 & Female==0 & Latino==1
replace  pw =1.16374269 if EventNumber==200804 & Female==0 & Asian==1
replace  pw = 1.034437947 if EventNumber==200804 & Female==0 & Other==1
replace  pw = 0.99612543 if EventNumber==200804 & Female==1 & White==1
replace  pw = 0.872807018 if EventNumber==200804 & Female==1 & Black==1
replace  pw = 0.930994152 if EventNumber==200804 & Female==1 & Latino==1
replace  pw = 0.840480832 if EventNumber==200804 & Female==1 & Asian==1
replace  pw = 0.77582846 if EventNumber==200804 & Female==1 & Other==1

replace  pw=1.052947053 if EventNumber==200805 & Female==0 & White==.
replace  pw= 0.974186308 if EventNumber==200805 & Female==1 & White==.
replace  pw= 1.011655012  if EventNumber==200805 & Female==. & White==1
replace  pw= 1.114885115 if EventNumber==200805 & Female==. & Black==1
replace  pw= 0.867132867 if EventNumber==200805 & Female==. & Latino==1
replace  pw= 0.867132867 if EventNumber==200805 & Female==. & Asian==1
replace  pw = 1.077346896 if EventNumber==200805 & Female==0& White==1
replace  pw = 1.734265734 if EventNumber==200805 & Female==0& Black==1
replace  pw =0.867132867 if EventNumber==200805 & Female==0 & Latino==1
replace  pw =0.867132867 if EventNumber==200805 & Female==0 & Asian==1
replace  pw =0.979020979 if EventNumber==200805 & Female==1 & White==1
replace  pw = 1.011655012 if EventNumber==200805 & Female==1 & Black==1
replace  pw = 0.867132867 if EventNumber==200805 & Female==1 & Latino==1
replace  pw = 0.867132867 if EventNumber==200805 & Female==1 & Asian==1

replace  pw= 1.046831956  if EventNumber==200806 & Female==0 & White==.
replace  pw= 0.975327041 if EventNumber==200806 & Female==1 & White==.
replace  pw= 1.0094451  if EventNumber==200806 & Female==. & White==1
replace  pw= 0.95959596 if EventNumber==200806 & Female==. & Black==1
replace  pw= 0.95959596 if EventNumber==200806 & Female==. & Latino==1
replace  pw= 0.95959596 if EventNumber==200806 & Female==. & Asian==1
replace  pw= 0.95959596 if EventNumber==200806 & Female==. & Other==1
replace  pw = 1.074747475 if EventNumber==200806 & Female==0& White==1
replace  pw = 0.95959596 if EventNumber==200806 & Female==0& Black==1
replace  pw = 0.95959596 if EventNumber==200806 & Female==0 & Latino==1
replace  pw = 0.95959596 if EventNumber==200806 & Female==0 & Other==1
replace  pw = 0.978411567 if EventNumber==200806 & Female==1 & White==1
replace  pw = 0.95959596 if EventNumber==200806 & Female==1 & Black==1
replace  pw = 0.95959596 if EventNumber==200806 & Female==1 & Latino==1
replace  pw = 0.95959596 if EventNumber==200806 & Female==1 & Asian==1
replace  pw = 0.95959596 if EventNumber==200806 & Female==1 & Other==1

replace  pw=1 if EventNumber==200807 & Female==0 & White==.
replace  pw= 1 if EventNumber==200807 & Female==1 & White==.
replace  pw= 1  if EventNumber==200807 & Female==. & White==1
replace  pw= 1 if EventNumber==200807 & Female==. & Black==1
replace  pw = 1 if EventNumber==200807 & Female==0& White==1
replace  pw =1 if EventNumber==200807 & Female==1 & White==1
replace  pw = 1 if EventNumber==200807 & Female==1 & Black==1
replace  pw = 1 if EventNumber==200807 & Female==1 & Latino==1

replace  pw= 1.070050225 if EventNumber==200808 & Female==0 & White==.
replace  pw= 0.975327041 if EventNumber==200808 & Female==1 & White==.
replace  pw= 0.976425284  if EventNumber==200808 & Female==. & White==1
replace  pw= 1.179487179 if EventNumber==200808 & Female==. & Black==1
replace  pw= 0.962846677 if EventNumber==200808 & Female==. & Latino==1
replace  pw= 3.36996337 if EventNumber==200808 & Female==. & Asian==1
replace  pw= 0.673992674 if EventNumber==200808 & Female==. & Other==1
replace  pw = 1.071475533 if EventNumber==200808 & Female==0& White==1
replace  pw = 1.155416013 if EventNumber==200808 & Female==0& Black==1
replace  pw = 0.919080919 if EventNumber==200808 & Female==0 & Latino==1
replace  pw = 0.673992674 if EventNumber==200808 & Female==0 & Other==1
replace  pw = 0.881375035 if EventNumber==200808 & Female==1 & White==1
replace  pw = 1.213186813 if EventNumber==200808 & Female==1 & Black==1
replace  pw = 1.123321123 if EventNumber==200808 & Female==1 & Latino==1
replace  pw = 2.021978022 if EventNumber==200808 & Female==1 & Asian==1
replace  pw = 0.673992674 if EventNumber==200808 & Female==1 & Other==1

replace  pw= 1.054791225  if EventNumber==200809 & Female==0 & White==.
replace  pw= 0.955774262 if EventNumber==200809 & Female==1 & White==.
replace  pw= 1.005529938  if EventNumber==200809 & Female==. & White==1
replace  pw= 1.308500478 if EventNumber==200809 & Female==. & Black==1
replace  pw= 0.981375358 if EventNumber==200809 & Female==. & Latino==1
replace  pw= 1.020630372 if EventNumber==200809 & Female==. & Asian==1
replace  pw= 1.570200573 if EventNumber==200809 & Female==. & Other==1
replace  pw = 1.044524729 if EventNumber==200809 & Female==0& White==1
replace  pw = 1.413180516 if EventNumber==200809 & Female==0& Black==1
replace  pw = 1.570200573 if EventNumber==200809 & Female==0 & Latino==1
replace  pw =0.89725747 if EventNumber==200809 & Female==0 & Asian==1
replace  pw = 1.570200573 if EventNumber==200809 & Female==0 & Other==1
replace  pw = 0.94338663 if EventNumber==200809 & Female==1 & White==1
replace  pw = 1.17765043 if EventNumber==200809 & Female==1 & Black==1
replace  pw = 0.785100287 if EventNumber==200809 & Female==1 & Latino==1
replace  pw = 1.308500478 if EventNumber==200809 & Female==1 & Asian==1
replace  pw = 1.570200573 if EventNumber==200809 & Female==1 & Other==1

replace  pw= 1.048519737 if EventNumber==200901 & Female==0 & White==.
replace  pw= 0.973958333 if EventNumber==200901 & Female==1 & White==.
replace  pw= 0.885416667  if EventNumber==200901 & Female==. & White==1
replace  pw= 1.521306818 if EventNumber==200901 & Female==. & Black==1
replace  pw= 0.95625 if EventNumber==200901 & Female==. & Latino==1
replace  pw= 1.1953125 if EventNumber==200901 & Female==. & Asian==1
replace  pw= 1.252232143 if EventNumber==200901 & Female==. & Other==1
replace  pw = 0.896484375 if EventNumber==200901 & Female==0& White==1
replace  pw = 1.59375 if EventNumber==200901 & Female==0& Black==1
replace  pw = 1.0625 if EventNumber==200901 & Female==0 & Latino==1
replace  pw = 1.9921875 if EventNumber==200901 & Female==0 & Other==1
replace  pw = 0.878188776 if EventNumber==200901 & Female==1 & White==1
replace  pw = 1.494140625 if EventNumber==200901 & Female==1 & Black==1
replace  pw = 0.796875 if EventNumber==200901 & Female==1 & Latino==1
replace  pw = 1.0625 if EventNumber==200901 & Female==1 & Asian==1
replace  pw = 0.99609375 if EventNumber==200901 & Female==1 & Other==1

replace  pw= 1.038567493  if EventNumber==200902 & Female==0 & White==.
replace  pw= 0.959913095 if EventNumber==200902 & Female==1 & White==.
replace  pw= 0.964669421  if EventNumber==200902 & Female==. & White==1
replace  pw= 1.355054037 if EventNumber==200902 & Female==. & Black==1
replace  pw= 1.078512397 if EventNumber==200902 & Female==. & Latino==1
replace  pw= 1.090495868 if EventNumber==200902 & Female==. & Asian==1
replace  pw= 0.838842975 if EventNumber==200902 & Female==. & Other==1
replace  pw = 1.00661157 if EventNumber==200902 & Female==0& White==1
replace  pw = 1.438016529 if EventNumber==200902 & Female==0& Black==1
replace  pw = 1.048553719 if EventNumber==200902 & Female==0 & Latino==1
replace  pw =1.1184573 if EventNumber==200902 & Female==0 & Asian==1
replace  pw = 0.838842975 if EventNumber==200902 & Female==0 & Other==1
replace  pw = 0.917134986 if EventNumber==200902 & Female==1 & White==1
replace  pw = 1.258264463 if EventNumber==200902 & Female==1 & Black==1
replace  pw = 1.174380165 if EventNumber==200902 & Female==1 & Latino==1
replace  pw = 1.078512397 if EventNumber==200902 & Female==1 & Asian==1

replace  pw= 0.983125108  if EventNumber==200903 & Female==0 & White==.
replace  pw= 1.024198384 if EventNumber==200903 & Female==1 & White==.
replace  pw= 0.991123129  if EventNumber==200903 & Female==. & White==1
replace  pw= 1.13352999 if EventNumber==200903 & Female==. & Black==1
replace  pw= 0.987545067 if EventNumber==200903 & Female==. & Latino==1
replace  pw= 0.84312148 if EventNumber==200903 & Female==. & Asian==1
replace  pw= 1.236578171 if EventNumber==200903 & Female==. & Other==1
replace  pw = 0.955907468 if EventNumber==200903 & Female==0& White==1
replace  pw = 1.159292035 if EventNumber==200903 & Female==0& Black==1
replace  pw = 1.214496418 if EventNumber==200903 & Female==0 & Latino==1
replace  pw =0.966076696 if EventNumber==200903 & Female==0 & Asian==1
replace  pw = 0.772861357 if EventNumber==200903 & Female==0 & Other==1
replace  pw = 1.03828849 if EventNumber==200903 & Female==1 & White==1
replace  pw = 1.0820059 if EventNumber==200903 & Female==1 & Black==1
replace  pw = 0.84312148 if EventNumber==200903 & Female==1 & Latino==1
replace  pw = 0.772861357 if EventNumber==200903 & Female==1 & Asian==1
replace  pw = 3.091445428 if EventNumber==200903 & Female==1 & Other==1

replace  pw= 1.070609319  if EventNumber==200904 & Female==0 & White==.
replace  pw= 0.945216908 if EventNumber==200904 & Female==1 & White==.
replace  pw= 1.022332506  if EventNumber==200904 & Female==. & White==1
replace  pw= 0.830645161 if EventNumber==200904 & Female==. & Black==1
replace  pw= 0.830645161 if EventNumber==200904 & Female==. & Latino==1
replace  pw = 1.107526882 if EventNumber==200904 & Female==0& White==1
replace  pw = 0.830645161 if EventNumber==200904 & Female==0& Black==1
replace  pw = 0.953703704 if EventNumber==200904 & Female==1 & White==1
replace  pw = 0.830645161 if EventNumber==200904 & Female==1 & Black==1
replace  pw = 0.830645161 if EventNumber==200904 & Female==1 & Latino==1

replace  pw= 1.072131148  if EventNumber==200905 & Female==0 & White==.
replace  pw= 0.909106383 if EventNumber==200905 & Female==1 & White==.
replace  pw= 1.030545455  if EventNumber==200905 & Female==. & White==1
replace  pw= 1.162666667 if EventNumber==200905 & Female==. & Black==1
replace  pw= 0.872 if EventNumber==200905 & Female==. & Latino==1
replace  pw= 0.872 if EventNumber==200905 & Female==. & Asian==1
replace  pw= 2.616 if EventNumber==200905 & Female==. & Other==1
replace  pw = 1.107675676 if EventNumber==200905 & Female==0& White==1
replace  pw = 1.453333333 if EventNumber==200905 & Female==0& Black==1
replace  pw = 0.872 if EventNumber==200905 & Female==0 & Latino==1
replace  pw =0.872 if EventNumber==200905 & Female==0 & Asian==1
replace  pw = 2.616 if EventNumber==200905 & Female==0 & Other==1
replace  pw = 0.934285714 if EventNumber==200905 & Female==1 & White==1
replace  pw = 0.872 if EventNumber==200905 & Female==1 & Black==1
replace  pw = 0.872 if EventNumber==200905 & Female==1 & Latino==1
replace  pw = 0.872 if EventNumber==200905 & Female==1 & Asian==1

replace  pw= 1.038120334  if EventNumber==200907 & Female==0 & White==.
replace  pw= 0.975620795 if EventNumber==200907 & Female==1 & White==.
replace  pw= 1.000534131  if EventNumber==200907 & Female==. & White==1
replace  pw= 0.969565217 if EventNumber==200907 & Female==. & Black==1
replace  pw= 0.881422925 if EventNumber==200907 & Female==. & Latino==1
replace  pw= 1.077294686 if EventNumber==200907 & Female==. & Asian==1
replace  pw= 1.322134387 if EventNumber==200907 & Female==. & Other==1
replace  pw = 1.034713868 if EventNumber==200907 & Female==0 & White==1
replace  pw = 1.028326746 if EventNumber==200907 & Female==0 & Black==1
replace  pw = 0.881422925 if EventNumber==200907 & Female==0 & Latino==1
replace  pw = 1.322134387 if EventNumber==200907 & Female==0 & Asian==1
replace  pw = 1.101778656 if EventNumber==200907 & Female==0 & Other==1
replace  pw = 0.981062038 if EventNumber==200907 & Female==1 & White==1
replace  pw = 0.881422925 if EventNumber==200907 & Female==1 & Black==1
replace  pw = 0.881422925 if EventNumber==200907 & Female==1 & Latino==1
replace  pw = 0.881422925 if EventNumber==200907 & Female==1 & Asian==1

replace  pw= 1.162960504 if EventNumber==200908 & Female==0 & White==.
replace  pw= 0.854961832 if EventNumber==200908 & Female==1 & White==.
replace  pw= 1.045352492  if EventNumber==200908 & Female==. & White==1
replace  pw= 1.099236641 if EventNumber==200908 & Female==. & Black==1
replace  pw= 0.8956743 if EventNumber==200908 & Female==. & Latino==1
replace  pw= 0.732824427 if EventNumber==200908 & Female==. & Asian==1
replace  pw= 2.198473282 if EventNumber==200908 & Female==. & Other==1
replace  pw = 1.236641221 if EventNumber==200908 & Female==0& White==1
replace  pw = 1.221374046 if EventNumber==200908 & Female==0& Black==1
replace  pw = 1.025954198 if EventNumber==200908 & Female==0 & Latino==1
replace  pw =0.732824427 if EventNumber==200908 & Female==0 & Asian==1
replace  pw = 1.465648855 if EventNumber==200908 & Female==0 & Other==1
replace  pw = 0.883700045 if EventNumber==200908 & Female==1 & White==1
replace  pw = 0.732824427 if EventNumber==200908 & Female==1 & Black==1
replace  pw = 0.732824427 if EventNumber==200908 & Female==1 & Latino==1
replace  pw = 0.732824427 if EventNumber==200908 & Female==1 & Asian==1

replace  pw= 0.988617886 if EventNumber==200909 & Female==0 & White==.
replace  pw= 1.020289855 if EventNumber==200909 & Female==1 & White==.
replace  pw= 0.777777778  if EventNumber==200909 & Female==. & White==1
replace  pw= 1.192156863 if EventNumber==200909 & Female==. & Black==1
replace  pw= 0.711111111 if EventNumber==200909 & Female==. & Latino==1
replace  pw= 0.711111111 if EventNumber==200909 & Female==. & Asian==1
replace  pw = 0.817777778 if EventNumber==200909 & Female==0& White==1
replace  pw = 1.151322751 if EventNumber==200909 & Female==0& Black==1
replace  pw = 0.711111111 if EventNumber==200909 & Female==0 & Latino==1
replace  pw = 0.711111111 if EventNumber==200909 & Female==0 & Asian==1
replace  pw = 0.711111111 if EventNumber==200909 & Female==1 & White==1
replace  pw = 1.258119658 if EventNumber==200909 & Female==1 & Black==1

replace  pw= 0.987441589  if EventNumber==200910 & Female==0 & White==.
replace  pw= 1.019966015 if EventNumber==200910 & Female==1 & White==.
replace  pw= 1.023639362  if EventNumber==200910 & Female==. & White==1
replace  pw= 1.144859813 if EventNumber==200910 & Female==. & Black==1
replace  pw= 0.888949973 if EventNumber==200910 & Female==. & Latino==1
replace  pw= 0.85864486 if EventNumber==200910 & Female==. & Asian==1
replace  pw= 2.060747664 if EventNumber==200910 & Female==. & Other==1
replace  pw = 0.959090108 if EventNumber==200910 & Female==0& White==1
replace  pw = 1.221183801 if EventNumber==200910 & Female==0& Black==1
replace  pw = 1.068535826 if EventNumber==200910 & Female==0 & Latino==1
replace  pw =0.91588785 if EventNumber==200910 & Female==0 & Asian==1
replace  pw = 1.373831776 if EventNumber==200910  & Female==0 & Other==1
replace  pw = 1.10192757 if EventNumber==200910 & Female==1 & White==1
replace  pw = 0.91588785 if EventNumber==200910 & Female==1 & Black==1
replace  pw = 0.686915888 if EventNumber==200910 & Female==1 & Latino==1
replace  pw = 0.824299065 if EventNumber==200910 & Female==1 & Asian==1

replace  pw= 1.012811634  if EventNumber==200911 & Female==0 & White==.
replace  pw= 0.980128894 if EventNumber==200911 & Female==1 & White==.
replace  pw= 1.052631579  if EventNumber==200911 & Female==. & White==1
replace  pw= 0.789473684 if EventNumber==200911 & Female==. & Black==1
replace  pw= 0.822368421 if EventNumber==200911 & Female==. & Latino==1
replace  pw= 0.877192982 if EventNumber==200911 & Female==. & Asian==1
replace  pw = 1.061120543 if EventNumber==200911 & Female==0& White==1
replace  pw = 0.822368421 if EventNumber==200911 & Female==0& Black==1
replace  pw = 0.845864662 if EventNumber==200911 & Female==0 & Latino==1
replace  pw =0.657894737 if EventNumber==200911 & Female==0 & Asian==1
replace  pw = 1.038781163 if EventNumber==200911 & Female==1 & White==1
replace  pw = 0.657894737 if EventNumber==200911 & Female==1 & Black==1
replace  pw = 0.789473684 if EventNumber==200911 & Female==1 & Latino==1
replace  pw = 0.986842105 if EventNumber==200911 & Female==1 & Asian==1

replace  pw= 1.060405644 if EventNumber==200912 & Female==0 & White==.
replace  pw= 0.936419753 if EventNumber==200912 & Female==1 & White==.
replace  pw= 0.997725796 if EventNumber==200912 & Female==. & White==1
replace  pw= 1.37037037 if EventNumber==200912 & Female==. & Black==1
replace  pw= 0.856481481 if EventNumber==200912 & Female==. & Latino==1
replace  pw= 0.959259259 if EventNumber==200912 & Female==. & Asian==1
replace  pw = 1.037566138 if EventNumber==200912 & Female==0& White==1
replace  pw = 1.37037037 if EventNumber==200912 & Female==0& Black==1
replace  pw = 1.027777778 if EventNumber==200912 & Female==0 & Latino==1
replace  pw =1.37037037 if EventNumber==200912 & Female==0 & Asian==1
replace  pw = 0.934343434 if EventNumber==200912 & Female==1 & White==1
replace  pw = 1.37037037 if EventNumber==200912 & Female==1 & Black==1
replace  pw = 0.685185185 if EventNumber==200912 & Female==1 & Latino==1
replace  pw = 0.856481481 if EventNumber==200912 & Female==1 & Asian==1


replace  pw= 1.011750454 if EventNumber==200913 & Female==0 & White==.
replace  pw= 0.988536953 if EventNumber==200913 & Female==1 & White==.
replace  pw= 0.988254756  if EventNumber==200913 & Female==. & White==1
replace  pw= 1.062271062 if EventNumber==200913 & Female==. & Black==1
replace  pw= 0.892307692 if EventNumber==200913 & Female==. & Latino==1
replace  pw= 1.041025641 if EventNumber==200913 & Female==. & Asian==1
replace  pw= 1.784615385 if EventNumber==200913 & Female==. & Other==1
replace  pw = 1.013592233 if EventNumber==200913 & Female==0& White==1
replace  pw = 1.029585799 if EventNumber==200913 & Female==0& Black==1
replace  pw = 0.892307692 if EventNumber==200913 & Female==0 & Latino==1
replace  pw = 1.070769231 if EventNumber==200913 & Female==0 & Asian==1
replace  pw = 0.892307692 if EventNumber==200913  & Female==0 & Other==1
replace  pw = 0.957598499 if EventNumber==200913 & Female==1 & White==1
replace  pw = 1.115384615 if EventNumber==200913 & Female==1 & Black==1
replace  pw = 0.892307692 if EventNumber==200913 & Female==1 & Latino==1
replace  pw = 1.041025641 if EventNumber==200913 & Female==1 & Asian==1
replace  pw= 2.676923077 if EventNumber==200913 & Female==1 & Other==1

replace  pw= 1.055555556   if EventNumber==201001 & Female==0 & White==.
replace  pw= 0.949404762 if EventNumber==201001 & Female==1 & White==.
replace  pw= 1.045508274 if EventNumber==201001 & Female==. & White==1
replace  pw= 0.805555556 if EventNumber==201001 & Female==. & Black==1
replace  pw= 0.805555556 if EventNumber==201001 & Female==. & Latino==1
replace  pw= 0.805555556 if EventNumber==201001 & Female==. & Asian==1
replace  pw=0.805555556 if EventNumber==201001 & Female==. & Other==1
replace  pw = 1.107638889 if EventNumber==201001 & Female==0 & White==1
replace  pw = 0.805555556 if EventNumber==201001 & Female==0 & Latino==1
replace  pw = 0.805555556 if EventNumber==201001 & Female==0 & Asian==1
replace  pw = 0.805555556 if EventNumber==201001 & Female==0 & Other==1
replace  pw = 0.980676329  if EventNumber==201001 & Female==1 & White==1
replace  pw = 0.805555556 if EventNumber==201001 & Female==1 & Black==1
replace  pw = 0.805555556 if EventNumber==201001 & Female==1 & Latino==1
replace  pw = 0.805555556 if EventNumber==201001 & Female==1 & Other==1

replace  pw= 1.119872561   if EventNumber==201002 & Female==0 & White==.
replace  pw= 0.933947773 if EventNumber==201002 & Female==1 & White==.
replace  pw= 1.024748251  if EventNumber==201002 & Female==. & White==1
replace  pw= 0.817204301 if EventNumber==201002 & Female==. & Black==1
replace  pw= 0.817204301  if EventNumber==201002 & Female==. & Latino==1
replace  pw= 1.089605735 if EventNumber==201002 & Female==. & Asian==1
replace  pw= 0.817204301 if EventNumber==201002 & Female==. & Other==1
replace  pw = 1.188660802 if EventNumber==201002 & Female==0 & White==1
replace  pw = 0.817204301 if EventNumber==201002 & Female==0 & Black==1
replace  pw = 0.817204301 if EventNumber==201002 & Female==0 & Latino==1
replace  pw = 0.936795174  if EventNumber==201002 & Female==1 & White==1
replace  pw = 0.817204301 if EventNumber==201002 & Female==1 & Black==1
replace  pw = 0.817204301 if EventNumber==201002 & Female==1 & Latino==1
replace  pw = 1.089605735 if EventNumber==201002 & Female==1 & Asian==1
replace  pw = 0.817204301 if EventNumber==201002 & Female==1 & Other==1

replace  pw= 0.96969697  if EventNumber==201003 & Female==0 & White==.
replace  pw= 1.044289044 if EventNumber==201003 & Female==1 & White==.
replace  pw= 0.893807642  if EventNumber==201003 & Female==. & White==1
replace  pw= 1.551515152 if EventNumber==201003 & Female==. & Black==1
replace  pw= 0.989090909  if EventNumber==201003 & Female==. & Latino==1
replace  pw= 1.163636364 if EventNumber==201003 & Female==. & Asian==1
replace  pw= 1.745454545 if EventNumber==201003 & Female==. & Other==1
replace  pw = 0.819834711 if EventNumber==201003 & Female==0 & White==1
replace  pw = 2.133333333 if EventNumber==201003 & Female==0 & Black==1
replace  pw = 1.066666667 if EventNumber==201003 & Female==0 & Latino==1
replace  pw = 1.163636364 if EventNumber==201003 & Female==0 & Asian==1
replace  pw = 1.024  if EventNumber==201003 & Female==1 & White==1
replace  pw = 0.96969697 if EventNumber==201003 & Female==1 & Black==1
replace  pw = 1.309090909 if EventNumber==201003 & Female==1 & Latino==1
replace  pw = 1.163636364 if EventNumber==201003 & Female==1 & Asian==1
replace  pw = 1.163636364 if EventNumber==201003 & Female==1 & Other==1


replace  pw= 1.000336134   if EventNumber==201004 & Female==0 & White==.
replace  pw= 0.99956427 if EventNumber==201004 & Female==1 & White==.
replace  pw= 1.081541582  if EventNumber==201004 & Female==. & White==1
replace  pw= 0.729411765 if EventNumber==201004 & Female==. & Black==1
replace  pw= 0.984705882  if EventNumber==201004 & Female==. & Latino==1
replace  pw= 0.795721925 if EventNumber==201004 & Female==. & Asian==1
replace  pw= 1.458823529 if EventNumber==201004 & Female==. & Other==1

replace  pw = 1.146218487 if EventNumber==201004 & Female==0 & White==1
replace  pw = 0.729411765 if EventNumber==201004 & Female==0 & Black==1
replace  pw = 0.923921569 if EventNumber==201004 & Female==0 & Latino==1
replace  pw = 0.729411765 if EventNumber==201004 & Female==0 & Asian==1
replace  pw = 1.458823529 if EventNumber==201004 & Female==0 & Other==1
replace  pw = 1.021176471  if EventNumber==201004 & Female==1 & White==1
replace  pw = 0.729411765 if EventNumber==201004 & Female==1 & Black==1
replace  pw = 1.167058824 if EventNumber==201004 & Female==1 & Latino==1
replace  pw = 0.850980392 if EventNumber==201004 & Female==1 & Asian==1


replace  pw= 1.12987013   if EventNumber==201005 & Female==0 & White==.
replace  pw= 0.920634921 if EventNumber==201005 & Female==1 & White==.
replace  pw= 0.748783069  if EventNumber==201005 & Female==. & White==1
replace  pw= 1.104761905  if EventNumber==201005 & Female==. & Latino==1
replace  pw= 1.767619048 if EventNumber==201005 & Female==. & Asian==1
replace  pw= 3.59047619 if EventNumber==201005 & Female==. & Other==1
replace  pw = 0.844817927 if EventNumber==201005 & Female==0 & White==1
replace  pw = 1.657142857 if EventNumber==201005 & Female==0 & Latino==1
replace  pw = 2.761904762 if EventNumber==201005 & Female==0 & Asian==1
replace  pw = 1.380952381 if EventNumber==201005 & Female==0 & Other==1
replace  pw = 0.69047619  if EventNumber==201005 & Female==1 & White==1
replace  pw =0.736507937 if EventNumber==201005 & Female==1 & Latino==1
replace  pw = 1.519047619 if EventNumber==201005 & Female==1 & Asian==1


replace  pw= 1.026115272   if EventNumber==201006 & Female==0 & White==.
replace  pw= 0.971183597 if EventNumber==201006 & Female==1 & White==.
replace  pw= 0.881414748  if EventNumber==201006 & Female==. & White==1
replace  pw= 1.140858506 if EventNumber==201006 & Female==. & Black==1
replace  pw= 1.011891892  if EventNumber==201006 & Female==. & Latino==1
replace  pw= 1.020768137 if EventNumber==201006 & Female==. & Asian==1
replace  pw= 1.517837838 if EventNumber==201006 & Female==. & Other==1
replace  pw = 0.96564952 if EventNumber==201006 & Female==0 & White==1
replace  pw = 1.533169533 if EventNumber==201006 & Female==0 & Black==1
replace  pw = 1.106756757 if EventNumber==201006 & Female==0 & Latino==1
replace  pw = 1.054054054 if EventNumber==201006 & Female==0 & Asian==1
replace  pw = 1.264864865 if EventNumber==201006 & Female==0 & Other==1
replace  pw = 0.950435181  if EventNumber==201006 & Female==1 & White==1
replace  pw = 1.124324324 if EventNumber==201006 & Female==1 & Black==1
replace  pw =1.054054054 if EventNumber==201006 & Female==1 & Latino==1
replace  pw = 0.996560197 if EventNumber==201006 & Female==1 & Asian==1
replace  pw = 2.52972973 if EventNumber==201006 & Female==1 & Other==1


replace  pw= 0.945736434   if EventNumber==201007 & Female==0 & White==.
replace  pw= 1.15620915 if EventNumber==201007 & Female==1 & White==.
replace  pw= 1.084444444  if EventNumber==201007 & Female==. & White==1
replace  pw= 0.970454545 if EventNumber==201007 & Female==. & Black==1
replace  pw= 0.903703704  if EventNumber==201007 & Female==. & Latino==1
replace  pw= 0.677777778 if EventNumber==201007 & Female==. & Asian==1
replace  pw= 0.677777778 if EventNumber==201007 & Female==. & Other==1
replace  pw = 0.881111111 if EventNumber==201007 & Female==0 & White==1
replace  pw = 0.953125 if EventNumber==201007 & Female==0 & Black==1
replace  pw = 1.016666667 if EventNumber==201007 & Female==0 & Latino==1
replace  pw = 0.677777778 if EventNumber==201007 & Female==0 & Asian==1
replace  pw = 0.677777778 if EventNumber==201007 & Female==0 & Other==1
replace  pw = 1.491111111  if EventNumber==201007 & Female==1 & White==1
replace  pw = 1.016666667 if EventNumber==201007 & Female==1 & Black==1
replace  pw =0.677777778 if EventNumber==201007 & Female==1 & Latino==1
replace  pw = 0.677777778 if EventNumber==201007 & Female==1 & Asian==1
replace  pw = 0.677777778 if EventNumber==201007 & Female==1 & Other==1

replace  pw= 1.139705882  if EventNumber==201008 & Female==0 & White==.
replace  pw= 0.868347339 if EventNumber==201008 & Female==1 & White==.
replace  pw= 0.828877005 if EventNumber==201008 & Female==. & White==1
replace  pw= 1.823529412 if EventNumber==201008 & Female==. & Black==1
replace  pw= 1.519607843  if EventNumber==201008 & Female==. & Latino==1
replace  pw= 1.06372549 if EventNumber==201008 & Female==. & Asian==1
replace  pw = 0.911764706 if EventNumber==201008 & Female==0 & White==1
replace  pw = 1.823529412 if EventNumber==201008 & Female==0 & Latino==1
replace  pw = 1.215686275 if EventNumber==201008 & Female==0 & Asian==1
replace  pw = 0.74291939  if EventNumber==201008 & Female==1 & White==1
replace  pw = 0.607843137 if EventNumber==201008 & Female==1 & Black==1
replace  pw =1.215686275 if EventNumber==201008 & Female==1 & Latino==1
replace  pw = 0.911764706 if EventNumber==201008 & Female==1 & Asian==1


replace  pw= 1.076252723   if EventNumber==201009 & Female==0 & White==.
replace  pw= 0.95 if EventNumber==201009 & Female==1 & White==.
replace  pw= 0.989583333  if EventNumber==201009 & Female==. & White==1
replace  pw= 0.703703704 if EventNumber==201009 & Female==. & Black==1
replace  pw= 1.407407407  if EventNumber==201009 & Female==. & Latino==1
replace  pw= 2.111111111 if EventNumber==201009 & Female==. & Asian==1
replace  pw = 1.032098765 if EventNumber==201009 & Female==0 & White==1
replace  pw = 0.703703704 if EventNumber==201009 & Female==0 & Latino==1
replace  pw = 0.952069717 if EventNumber==201009 & Female==1 & White==1
replace  pw = 0.703703704 if EventNumber==201009 & Female==1 & Black==1
replace  pw =1.407407407 if EventNumber==201009 & Female==1 & Latino==1
replace  pw = 0.703703704 if EventNumber==201009 & Female==1 & Asian==1


replace  pw= 0.976601458  if EventNumber==201010 & Female==0 & White==.
replace  pw= 1.039608003 if EventNumber==201010 & Female==1 & White==.
replace  pw= 1.007645068  if EventNumber==201010 & Female==. & White==1
replace  pw= 1.036568214 if EventNumber==201010 & Female==. & Black==1
replace  pw= 1.029837251  if EventNumber==201010 & Female==. & Latino==1
replace  pw= 1.017721519 if EventNumber==201010 & Female==. & Asian==1
replace  pw= 0.848101266 if EventNumber==201010 & Female==. & Other==1
replace  pw = 0.995597138 if EventNumber==201010 & Female==0 & White==1
replace  pw = 0.848101266 if EventNumber==201010 & Female==0 & Black==1
replace  pw = 1.090415913 if EventNumber==201010 & Female==0 & Latino==1
replace  pw = 0.848101266 if EventNumber==201010 & Female==0 & Asian==1
replace  pw = 0.848101266 if EventNumber==201010 & Female==0 & Other==1
replace  pw = 1.011197663  if EventNumber==201010 & Female==1 & White==1
replace  pw = 1.41350211 if EventNumber==201010 & Female==1 & Black==1
replace  pw =0.96925859 if EventNumber==201010 & Female==1 & Latino==1
replace  pw = 1.696202532 if EventNumber==201010 & Female==1 & Asian==1
replace  pw = 0.848101266 if EventNumber==201010 & Female==1 & Other==1
********************************************************************************
					       **Declare Survey Design**
********************************************************************************	

*Setting survey weight by pw and EventNumber
svyset Caseid [pweight = pw], strata(EventNumber)
save "antiwar_weighted.dta",replace 
exit 
