capture log close
log using "part2_imputedata", replace text

//  project:     A White Social Movement...
//  author:      Fabio Rojas, Michael T. Heaney, Muna Adem
//  dataset:     antiwar_weighted 
//  date:	     2019-09-05
//  updated:     2023/03/04
//  contact:     munaadem@iu.edu



//Task1:       Clean/recode some variables
//Task2:       Impute Data using MICE


version 	17.0
clear 		all
set 		linesize 80
matrix drop _all
set more 	off, permanently

// open dataset 
use "antiwar_weighted.dta", clear 
********************************************************************************
						**Cleaning and Descriptives**
********************************************************************************
svyset

// Recreate Contact 

gen ContactedOrg=1
replace ContactedOrg=0 if Contact==2
replace ContactedOrg=0 if Contact==0
tab ContactedOrg Contact, m

// Need race, age, gender, education, income, distance;
// all ok except distance, education, and income;
// let’s log transform and dichotomize education

gen log_distance=log(Distance+1)

recode Educ (1/4=0 "Less than College") (5/7=1 "College or Higher"), ///
            gen (college_or_higher)

recode Past_Training 2=.

/*
                     Reproducing Descriptive Table
asdoc sum ContactedOrg Past_Protest Past_Training Black White Latino Asian ///
    Other_Race Age Female college_or_higher log_distance Democratic ///
	Republican Political_Attitudes Radical_Pol_Att 
*/


********************************************************************************
						**Impute Data - MICE **
********************************************************************************

* Do not impute the dependent variables 
mi set flong
mi register imp Black Asian Latino White Age college_or_higher Female Income  ///
   Democratic Political_Attitudes Radical_Pol_Att log_distance 
mi register reg ContactedOrg Past_Training Past_Protest	   

misstable sum Black Asian Latino White Age Female college_or_higher  ///
   Democratic Republican Political_Attitudes Radical_Pol_Att Income log_distance ///
   Past_Training Past_Protest
		   
*Impute Data
mi impute chained (pmm, knn(10)) Age Income log_distance Political_Attitudes ///
   (logit) Black Asian Latino White Female Democratic college_or_higher  ///
   Radical_Pol_Att=i.ContactedOrg i.Past_Training ///
   i.Past_Protest, rseed(23413) augment add(100) force
 	    
mi convert wide, clear
browse

* Recheck Imputations
sum _1_Female _1_college_or_higher _1_Black _1_Latino _1_Asian _1_White _1_log_distance ///
    _1_Democratic _1_Female _1_Black log_distance _1_Democratic ///
     _1_Age _1_Income  _1_Political_Attitudes  ///
	 _1_Radical_Pol_Att if _mi_miss == 1

*save data
save antiwar_imputed.dta, replace





