capture log close
log using "part3_mainmodels", replace text

//  project:     A White Social Movement...
//  author:      Fabio Rojas, Michael T. Heaney, Muna Adem
//  dataset:     antiwar_weighted 
//  date:	     2019-09-05
//  updated:     2023/03/04
//  contact:     munaadem@iu.edu


//Task1:       Produce Descriptives using Imputed Data 
//Task2:       Running Main Individual Level Models 


version 	15.0
clear 		all
set 		linesize 80
matrix drop _all
set more 	off, permanently

// open dataset 
use "antiwar_imputed.dta", clear 
********************************************************************************
				           ** Imputed Descriptives**
********************************************************************************
mi svyset 


mi estimate: mean Female college_or_higher Democratic Radical_Pol_Att ///
             Age Political_Attitudes log_distance Income ContactedOrg ///
			 Past_Training Past_Protest 
			 
misstable sum Black Asian Latino White Other_Race Age Female Income  ///
Democratic Republican Political_Attitudes Radical_Pol_Att log_distance ///
Past_Training Past_Protest

gen race=.
replace race=1 if White==1
replace race=2 if Black==1
replace race=3 if Latino==1
replace race=4 if Asian==1
replace race=5 if Other_Race==1

label define racefmt 1 "White" 2 "Black" 3 "Latino" 4 "Asian" 5 "Other"
label val race racefmt
********************************************************************************
				             ** Main Models**
********************************************************************************	 

                       **//Reproducing Table 3: 

         ******* // Contact Models 1.1 and 1.2  // ********
mi estimate:logit ContactedOrg i.race 
mi estimate:logit ContactedOrg i.race Age Female ///
            college_or_higher Income log_distance Democratic  ///
			Political_Attitudes Radical_Pol_Att
		 	
      ******* // Past Protest Models:  2.1 and 2.2 // ********
mi estimate:logit Past_Protest i.race 
mi estimate:logit Past_Protest i.race Age Female ///
      college_or_higher Income log_distance Democratic  ///
	  Political_Attitudes Radical_Pol_Att
  	  
       ******* // Past Traning Models:  3.1 and 3.2 // ********  
mi estimate:logit Past_Training i.race 
mi estimate:logit Past_Training i.race Age ///
            Female college_or_higher Income log_distance ///
		  Democratic  Political_Attitudes Radical_Pol_Att	
		 
                     **//Reproducing Table 4-8//**: 

* Past Protest - Including Contact


mi estimate:logit Past_Protest ContactedOrg i.race Age Female ///
      college_or_higher Income log_distance Democratic  ///
	  Political_Attitudes Radical_Pol_Att 
	  
* Past Training - Including Contact

mi estimate:logit Past_Training ContactedOrg i.race 
mi estimate:logit Past_Training ContactedOrg i.race Age ///
          Female college_or_higher Income log_distance ///
		  Democratic  Political_Attitudes Radical_Pol_Att	

	 
* No contact subsample
mi estimate:logit Past_Protest i.race if ContactedOrg==0
mi estimate:logit Past_Protest i.race Age Female ///
      college_or_higher Income log_distance Democratic  ///
	  Political_Attitudes Radical_Pol_Att if ContactedOrg==0
	  
* Org Contact Sample
mi estimate:logit Past_Protest i.race if ContactedOrg==1
mi estimate:logit Past_Protest i.race Age Female ///
      college_or_higher Income log_distance Democratic  ///
	  Political_Attitudes Radical_Pol_Att if ContactedOrg==1
	 

* Without Orgs contact sample	   
mi estimate:logit Past_Training  i.race if ContactedOrg==0
mi estimate:logit Past_Training i.race Age ///
          Female college_or_higher Income log_distance ///
		  Democratic  Political_Attitudes Radical_Pol_Att if ContactedOrg==0
		  
* With Orgs contact sample	  
mi estimate:logit Past_Training  i.race if ContactedOrg==1
mi estimate:logit Past_Training i.race Age ///
          Female college_or_higher Income log_distance ///
		  Democratic  Political_Attitudes Radical_Pol_Att if ContactedOrg==1

save, replace
log close 
