capture log close
log using "part4_orgsdata", replace text


//  project:     A White Social Movement...
//  author:      Fabio Rojas, Michael T. Heaney, Muna Adem
//  dataset:     antiwar_weighted 
//  date:	     2019-09-05
//  updated:     2023/03/02
//  contact:     munaadem@iu.edu


//Task1:       Merge EdgeList with Individual Data 
//Task2:       Create Race data by Abbreviation
//Task3:       Create Race data by Abbreviation
//Task4:       Add Group Specific Frequence
//Task5:       Add Group Specific Frequence to Overall Freq
//Task6:       Create Frequence for tables 
//Task7:       Test for Normality 


version 	17.0
clear 		all
set 		linesize 80
matrix drop _all
set more 	off, permanently

********************************************************************************
                ** Merge EdgeList with Individual Data**
********************************************************************************
use "edgelist_20072010.dta", clear
sort Caseid
save, replace 


use "individual_all.dta", clear
keep Caseid White Black Latino Asian Other_Race Contact
sort Caseid
save, replace 
merge Caseid using edgelist_20072010.dta
save individual_all-merged.dta, replace 

********************************************************************************
                  ** Create Race data by Abbreviation **
********************************************************************************

sort Abbreviation White
drop _merge
save white.dta,replace 

use "individual_all-merged.dta", clear 
sort Abbreviation Black
drop _merge
save black.dta,replace 

use "individual_all-merged.dta", clear 
sort Abbreviation Latino
drop _merge
save latino.dta,replace 

use "individual_all-merged.dta", clear 
drop _merge
sort Abbreviation Asian
save asian.dta,replace 

********************************************************************************
                       **Add Group Specific Frequence**
********************************************************************************
use "Tablewhite-Abbbrev.dta", clear
sort Abbreviation
save,replace

use "Tableblack-Abbbrev.dta", clear
sort Abbreviation
save,replace

use "Tablelatino-Abbbrev.dta", clear
sort Abbreviation
save,replace

use "Tableasian-Abbbrev.dta", clear
sort Abbreviation
save,replace

********************************************************************************
                      **Add Group Specific Frequence to Overall Freq**
********************************************************************************

* Add White freq Colum. 
use  "overall_abbrev.dta", clear 
sort Abbreviation
save, replace

merge Abbreviation using "Tablewhite-Abbbrev.dta"
sort Abbreviation
drop _merge
save white_freq.dta, replace

use  "overall_abbrev.dta", clear 
merge Abbreviation using "white_freq.dta"
sort Abbreviation
drop _merge
save overall_abbrev1.dta, replace

*** Add Black freq. column 
use  "overall_abbrev.dta", clear 
sort Abbreviation
save, replace

merge Abbreviation using "Tableblack-Abbbrev.dta"
sort Abbreviation
drop _merge
save black_freq.dta, replace

use  "overall_abbrev1.dta", clear 
merge Abbreviation using "black_freq.dta"
sort Abbreviation
drop _merge
save overall_abbrev2.dta, replace


*** Add Latino freq. column  
use  "overall_abbrev.dta", clear 
sort Abbreviation
save, replace

merge Abbreviation using "Tablelatino-Abbbrev.dta"
sort Abbreviation
drop _merge
save latino_freq.dta, replace

use  "overall_abbrev2.dta", clear 
merge Abbreviation using "latino_freq.dta"
sort Abbreviation
drop _merge
save overall_abbrev3.dta, replace

*** Add Asian freq. column 
use  "overall_abbrev.dta", clear 
sort Abbreviation
save, replace

merge Abbreviation using "Tableasian-Abbbrev.dta"
sort Abbreviation
drop _merge
save asian_freq.dta, replace

use  "overall_abbrev3.dta", clear 
merge Abbreviation using "asian_freq.dta"
sort Abbreviation
drop _merge
save overall_abbrev_final.dta, replace

********************************************************************************
                    **Generate Group Specific Frequence for Tables**
********************************************************************************

**** frequency for top 20 organizationss
use "overall_abbrev_final.dta", clear
gsort -Frequency
list Abbreviation Frequency n_white n_black n_latino n_asian in 1/20

*** frequency by groups
gsort -n_white
list Abbreviation Frequency n_white in 1/20

gsort -n_black
list Abbreviation Frequency n_black in 1/20

gsort -n_latino
list Abbreviation Frequency n_latino in 1/20

gsort -n_asian
list Abbreviation Frequency n_asian in 1/20

**** new percent variable by group 
*White Percent 
gen perWhite = 100 * n_white/Frequency
list Abbreviation Frequency n_white perWhite in 1/20

*Black Percent 
gen perBlack = 100 * n_black/Frequency
list Abbreviation Frequency n_black perBlack in 1/20

*Latino Percent 
gen perLatino = 100 * n_latino/Frequency
list Abbreviation Frequency n_latino perLatino in 1/20

*Latino Percent 
gen perAsian = 100 * n_asian/Frequency
list Abbreviation Frequency n_asian perAsian in 1/20

list Abbreviation Frequency n_white n_black n_latino n_asian ///
      perWhite perBlack perLatino perAsian in 1/10

********************************************************************************
                       **Test for normality **
********************************************************************************

hist perWhite, frequency normal
swilk perWhite

hist perBlack, frequency normal
swilk perBlack

hist perLatino,frequency normal
swilk perLatino 

hist perAsian, frequency normal
swilk perAsian

log close